@@ -5,7 +5,8 @@ The shapicant module implements a feature selection algorithm based on SHAP and
 from ._base import BaseSelector
 from ._pandas_selector import PandasSelector
 from ._spark_selector import SparkSelector
+from ._spark_udf_selector import SparkUdfSelector
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 
-__all__ = ["BaseSelector", "PandasSelector", "SparkSelector"]
+__all__ = ["BaseSelector", "PandasSelector", "SparkSelector", "SparkUdfSelector"]
